#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
SUMMARY __init__.py

Copyright (C) 2017 Canux CHENG.
All rights reserved.

LICENSE GNU General Public License v3.0.

:author: Canux CHENG canuxcheng@gmail.com
:version: 1.2.0
:since: Wed 01 Jan 2017 09:13:48 AM EDT

DESCRIPTION:
"""

__version__ = "1.9.1"
__author__ = "Canux CHENG"
